@@ -1741,6 +1741,28 @@ mod tests {
         assert!(!bitfield.get_bit(7));
     }
 
+    #[test]
+    fn bitfield_full_field_size_u32() {
+        #[bitfield(u32)]
+        pub struct Bitfield {
+            data: u32,
+        }
+
+        let bitfield = Bitfield::from_bits(0xaabbccdd);
+        assert_eq!(bitfield.data(), 0xaabbccdd);
+    }
+
+    #[test]
+    fn bitfield_full_field_size_u64() {
+        #[bitfield(u64)]
+        pub struct Bitfield {
+            data: u64,
+        }
+
+        let bitfield = Bitfield::from_bits(0x11223344aabbccdd);
+        assert_eq!(bitfield.data(), 0x11223344aabbccdd);
+    }
+
     #[test]
     fn bitfield_set_bit() {
         #[bitfield(u8, bit_ops = true)]
@@ -2003,4 +2025,34 @@ mod tests {
             __: u32,
         }
     }
+
+    #[test]
+    fn bitfield_neg_inverts_bits() {
+        #[bitfield(u32, neg = true)]
+        pub struct Bitfield {
+            #[bits(5, default = 0xC)]
+            a: u8,
+            #[bits(default = 0x34)]
+            b: u8,
+            #[bits(default = 0x56)]
+            c: u8,
+            #[bits(10, default = 0x78)]
+            d: u16,
+            #[bits(default = true)]
+            e: bool,
+        }
+
+        let builder = Bitfield::new();
+
+        assert_eq!(builder.a(), 0xC);
+        assert_eq!(builder.b(), 0x34);
+        assert_eq!(builder.c(), 0x56);
+        assert_eq!(builder.d(), 0x78);
+        assert!(builder.e());
+        assert_eq!(builder.neg_a(), 0x13);
+        assert_eq!(builder.neg_b(), 0xCB);
+        assert_eq!(builder.neg_c(), 0xA9);
+        assert_eq!(builder.neg_d(), 0x387);
+        assert!(!builder.neg_e());
+    }
 }
